#
# spec file for package python3-IPython
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-IPython
Version:        3.2.2
Release:        3.17
Source0:        https://pypi.python.org/packages/source/i/ipython/ipython-%{version}.tar.gz
Source1:        ipython3-icons.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://ipython.scipy.org/
Summary:        An Enhanced Interactive Python Shell
License:        BSD-3-Clause
Group:          Development/Languages/Python
BuildArch:      noarch
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-Cython
BuildRequires:  python3-curses
BuildRequires:  python3-devel
BuildRequires:  python3-nose >= 0.10.1
BuildRequires:  python3-opengl
BuildRequires:  python3-pexpect
BuildRequires:  python3-pymongo
BuildRequires:  python3-pyzmq-devel >= 2.1.11
BuildRequires:  python3-setuptools
BuildRequires:  python3-xml
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
Requires:       python3-Jinja2
Requires:       python3-pexpect
Requires:       python3-pyzmq >= 2.1.11
Requires:       python3-tk
Requires:       python3-xml
Recommends:     python3-curses
Recommends:     python3-pymongo
# not available yet upstream
#Recommends:       python3-wxWidgets
# qtconsole
BuildRequires:  python3-Pygments
BuildRequires:  python3-matplotlib
BuildRequires:  python3-qt4-devel
Recommends:     python3-Pygments
Recommends:     python3-matplotlib
Recommends:     python3-qt4
#ipython notebook
BuildRequires:  python3-tornado >= 4.0
Recommends:     python3-tornado >= 4.0
BuildRequires:  python3-mistune >= 0.5
Recommends:     python3-mistune >= 0.5
#ipython nbformat
BuildRequires:  python3-jsonschema
Requires:       python3-jsonschema
#documentation
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  python3-Sphinx >= 0.3
BuildRequires:  python3-numpydoc

%description
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

Main features:
* Comprehensive object introspection.
* Input history that is persistent across sessions.
* Caching of output results during a session with automatically
   generated references.
* Readline-based name completion.
* Extensible system of 'magic' commands for controlling the
   environment and performing many tasks related either to IPython
   or the operating system.
* Configuration system with easy switching between different setups
   (simpler than changing $PYTHONSTARTUP environment variables every
   time).
* Session logging and reloading.
* Extensible syntax processing for special purpose situations.
* Access to the system shell with user-extensible alias system.
* Easily embeddable in other Python programs.
* Integrated access to the pdb debugger and the Python profiler.


%package doc
Summary:        An Enhanced Interactive Python Shell documentation
Group:          Documentation/Other
Recommends:     %{name} = %{version}

%description doc
IPython provides a replacement for the interactive python (Python)
interpreter with extra functionality.

This package contains comprehensive documentation for IPython in
html format, as well as examples of usage.

%prep
%setup -q -n ipython-%{version}

# Get rid of library shebangs
find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} \;

%build
export CFLAGS="%{optflags}"
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# move automatically installed documentation to the right directory
install -d -m 755 %{buildroot}%{_docdir}/
#mv -f %{buildroot}/usr/share/doc/IPython/ %{buildroot}%{_docdir}/%{name}

# does not seem to work with python 3
#make docs
#pushd docs
#sed -i 's/python/python3/g' Makefile
#2to3 -w ./
#PYTHONPATH=$PYTHONPATH:%{buildroot}%{python3_sitelib} make html
#rm build/html/.buildinfo
#mv build/html %{buildroot}%{_docdir}/%{name}/
#popd

# Fix man pages
for i in %{buildroot}%{_mandir}/man1/*; do mv "$i" "${i%%.1}3.1"; done

# remove hidden files
rm -f %{buildroot}/%{python3_sitelib}/IPython/.git_commit_info.ini
rm -f %{buildroot}/%{_docdir}/%{name}/manual/.buildinfo

# remove all executables that don't follow the bin/*3 convention for python3
rm %{buildroot}/%{_bindir}/ipcluster
rm %{buildroot}/%{_bindir}/ipcontroller
rm %{buildroot}/%{_bindir}/ipengine
rm %{buildroot}/%{_bindir}/iptest
rm %{buildroot}/%{_bindir}/ipython

# Fix .desktop files for python 3
mv examples/IPython\ Kernel/ipython.desktop  ./ipython3.desktop
mv examples/IPython\ Kernel/ipython-qtconsole.desktop ./ipython3-qtconsole.desktop

sed -i 's/Python/Python 3/g' *.desktop
sed -i 's/ipython/ipython3/g' *.desktop
sed -i 's/Pylab/Pylab3/g' *.desktop

%if 0%{?suse_version}
%fdupes %{buildroot}/%{_docdir}

# install .desktop files
sed -i 's/gnome-netstatus-idle/ipython3/g' *.desktop
%suse_update_desktop_file -r -i ipython3 System TerminalEmulator
%suse_update_desktop_file -r -i ipython3-qtconsole System TerminalEmulator
%endif

# install icons
tar xf %{S:1} -C %{buildroot}%{_datadir}

%files
%defattr(-,root,root)
%doc COPYING.rst README.rst
%{_bindir}/ipcluster3
%{_bindir}/ipcontroller3
%{_bindir}/ipengine3
%{_bindir}/iptest3
%{_bindir}/ipython3
%{_mandir}/man1/ipcluster3.1.gz
%{_mandir}/man1/ipcontroller3.1.gz
%{_mandir}/man1/ipengine3.1.gz
%{_mandir}/man1/ipython3.1.gz
%{_datadir}/applications/ipython3-qtconsole.desktop
%{_datadir}/applications/ipython3.desktop
%{_datadir}/icons/hicolor/
%{python3_sitelib}/IPython
%{python3_sitelib}/ipython-%{version}-py*.egg-info

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/COPYING.rst
%exclude %{_docdir}/%{name}/README.rst

%changelog
* Wed Sep 23 2015 toddrme2178@gmail.com
- Update to 3.2.2
  * This is a critical security update.
    Addresses vulnerabilities when files have maliciously crafted filenames (CVE-2015-6938),
    or vulnerability when opening text files with malicious binary content (CVE pending).
* Wed Jul 29 2015 toddrme2178@gmail.com
- Add python3-pexpect dependency, which is now python3 compatible.
* Mon Jul 13 2015 arun@gmx.de
- update to version 3.2.1:
  * IPython 3.2.1 is a small bugfix release, primarily for cross-site
    security fixes in the notebook. Users are strongly encouraged to
    upgrade immediately. There are also a few small unicode and
    nbconvert-related fixes
* Wed Jul  1 2015 toddrme2178@gmail.com
- update to version 3.2.0:
  * IPython 3.2 contains important security fixes. Users are
    strongly encouraged to upgrade immediately.
  * Highlights:
  - A security improvement that set the secure attribute to login cookie to prevent them to be sent over http
  - Revert the face color of matplotlib axes in the inline backend to not be transparent.
  - Enable mathjax safe mode by default
  - Fix XSS vulnerability in JSON error messages
  - Various widget-related fixes
* Sat Apr  4 2015 arun@gmx.de
- update to version 3.1.0:
  * Highlights:
    + Various focus jumping and scrolling fixes in the notebook.
    + Various message ordering and widget fixes in the notebook.
    + Images in markdown and output are confined to the notebook
    width. An .unconfined CSS class is added to disable this
    behavior per-image. The resize handle on output images is
    removed.
    + Improved ordering of tooltip content for Python functions,
    putting the signature at the top.
    + Fix UnicodeErrors when displaying some objects with unicode
    reprs on Python 2.
    + Set the kernel’s working directory to the notebook directory
    when running nbconvert --execute, so that behavior matches the
    live notebook.
    + Allow setting custom SSL options for the tornado server with
    NotebookApp.ssl_options, and protect against POODLE with default
    settings by disabling SSLv3.
    + Fix memory leak in the IPython.parallel Controller on Python 3.
  * See Issues closed in the 3.x development cycle for details.
* Tue Mar  3 2015 toddrme2178@gmail.com
- Drop gnome-icon-theme BuildRequires: the theme no longer exists
  (it was merged and renamed to Adwaita-icon-theme). Instead,
  package the icons in a tarball and install them during build.
- Reorganizes requirements a little.
* Sat Feb 28 2015 arun@gmx.de
- specifle:
  * added mistune, jsonschema requirement
  * updated some version numbers for requirements
  * removed pandoc requirement
- update to version 3.0.0:
  * Using different kernels
  * typing unicode identifiers
  * new widgets
  * lots of other changes, see
    http://ipython.org/ipython-doc/3/whatsnew/version3.html
* Tue Feb 10 2015 arun@gmx.de
- specfile:
  * removed modname variable
- update to version 2.4.1:
  * backport read support for nbformat v4 from IPython 3
  * support for PyQt5 in the kernel (not QtConsole)
  * support for Pygments 2.0
* Sat Jan  3 2015 arun@gmx.de
- specfile:
  * updated copyright year
  * added Jinja2 requirement for notebook and nbconvert (bnc#911524)
* Wed Nov 26 2014 arun@gmx.de
- update to 2.3.1
  * don’t use text mode in mkstemp
  * Notebook.ipynb CR+LF turned into CR+CR+LF
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 2.3.0
  * Bugfix release
* Thu Aug 28 2014 toddrme2178@gmail.com
- Add pandoc dependency for nbconvert notebook converter.
  This is only available for openSUSE > 13.1.
- Change some dependencies that are not required for basic
  functionality to Recommends.
* Sat Aug  9 2014 toddrme2178@gmail.com
- Update to 2.2.0
  * Bugfix release
* Tue Jul 15 2014 toddrme2178@gmail.com
- Update to 2.1.0
  * BugFix release
* Thu Apr  3 2014 arun@gmx.de
- updated to 2.0.0
  The principal milestones of 2.0 are:
  * interactive widgets for the notebook
  * directory navigation in the notebook dashboard
  * persistent URLs for notebooks
  * a new modal user interface in the notebook
  * a security model for notebooks
  more details at http://ipython.org/ipython-doc/2/whatsnew/version2.0.html
  * changes in spec file:
  - manual remove binaries that don't end in *3
  - added dependencies matplotlib, numpydoc, updated version for tornado
  - logger, color and irunner are not provided anymore, remove from file list
  - Copying is now in rst format
  - name and location of desktop files changed
  - removed if case for >12.2 version, since IPython only builds for >12.2
* Fri Mar  7 2014 arun@gmx.de
- update to 1.2.1 (including 1.2.0)
  Pull Requests (38):
  1.2.1:
    PR #4372: Don’t assume that SyntaxTB is always called with a SyntaxError
    PR #5166: remove mktemp usage
    PR #5163: Simplify implementation of TemporaryWorkingDirectory.
    PR #5105: add index to format to support py2.6
  1.2.0:
    PR #4972: Work around problem in doctest discovery in Python 3.4 with PyQt
    PR #4934: ipython profile create respects –ipython-dir
    PR #4845: Add Origin Checking.
    PR #4928: use importlib.machinery when available
    PR #4849: Various unicode fixes (mostly on Windows)
    PR #4880: set profile name from profile_dir
    PR #4908: detect builtin docstrings in oinspect
    PR #4909: sort dictionary keys before comparison, ordering is not guaranteed
    PR #4903: use https for all embeds
    PR #4868: Static path fixes
    PR #4820: fix regex for cleaning old logs with ipcluster
    PR #4840: Error in Session.send_raw()
    PR #4762: whitelist alphanumeric characters for cookie_name
    PR #4748: fix race condition in profiledir creation.
    PR #4720: never use ssh multiplexer in tunnels
    PR #4738: don’t inject help into user_ns
    PR #4722: allow purging local results as long as they are not outstanding
    PR #4668: Make non-ASCII docstring unicode
    PR #4639: Minor import fix to get qtconsole with –pylab=qt working
    PR #4453: Play nice with App Nap
    PR #4609: Fix bytes regex for Python 3.
    PR #4488: fix typo in message spec doc
    PR #4346: getpass() on Windows & Python 2 needs bytes prompt
    PR #4230: Switch correctly to the user’s default matplotlib backend after inline.
    PR #4214: engine ID metadata should be unicode, not bytes
    PR #4232: no highlight if no language specified
    PR #4218: Fix display of SyntaxError when .py file is modified
    PR #4217: avoid importing numpy at the module level
    PR #4213: fixed dead link in examples/notebooks readme to Part 3
    PR #4183: ESC should be handled by CM if tooltip is not on
    PR #4193: Update for #3549: Append Firefox overflow-x fix
    PR #4205: use TextIOWrapper when communicating with pandoc subprocess
    PR #4204: remove some extraneous print statements from IPython.parallel
    PR #4201: HeadingCells cannot be split or merged
  Issues (17):
  1.2.1:
    [#5101]: IPython 1.2.0: notebook fail with “500 Internal Server Error”
  1.2.0:
    [#4892]: IPython.qt test failure with python3.4
    [#4810]: ipcluster bug in clean_logs flag
    [#4765]: missing build script for highlight.js
    [#4761]: ipv6 address triggers cookie exception
    [#4721]: purge_results with jobid crashing - looking for insight
    [#4602]: “ipcluster stop” fails after “ipcluster start –daemonize” using python3.3
    [#3386]: Magic %%paste not working in Python 3.3.2. TypeError: Type str doesn’t support the buffer API
    [#4485]: Incorrect info in “Messaging in IPython” documentation.
    [#4351]: /parallel/apps/launcher.py error
    [#4334]: NotebookApp.webapp_settings static_url_prefix causes crash
    [#4039]: Celltoolbar example issue
    [#4256]: IPython no longer handles unicode file names
    [#4122]: Nbconvert [windows]: Inconsistent line endings in markdown cells exported to latex
    [#3819]: nbconvert add extra blank line to code block on Windows.
    [#4203]: remove spurious print statement from parallel annoted functions
    [#4200]: Notebook: merging a heading cell and markdown cell cannot be undone
* Sun Nov 24 2013 oleg@grodno.ru
- python3-tk is needed for working with clipboard.
- Added python3-tk as a required dependency.
* Sun Nov 24 2013 oleg@grodno.ru
- Added python3-tk as a required dependency
* Sat Nov 16 2013 arun@gmx.de
- update to 1.1.0, mostly bugfixes. Here is the list of changes
  Pull Requests (58):
    PR #4188 - Allow user_ns trait to be None
    PR #4189 - always fire LOCAL_IPS.extend(PUBLIC_IPS)
    PR #4174 - various issues in markdown and rst templates
    PR #4178 - add missing data_javascript
    PR #4181 - nbconvert: Fix, sphinx template not removing new lines from headers
    PR #4043 - don't 'restore_bytes' in from_JSON
    PR #4163 - Fix for incorrect default encoding on Windows.
    PR #4136 - catch javascript errors in any output
    PR #4171 - add nbconvert config file when creating profiles
    PR #4125 - Basic exercise of ipython [subcommand] -h and help-all
    PR #4085 - nbconvert: Fix sphinx preprocessor date format string for Windows
    PR #4159 - don't split .cell and div.cell CSS
    PR #4158 - generate choices for --gui configurable from real mapping
    PR #4065 - do not include specific css in embedable one
    PR #4092 - nbconvert: Fix for unicode html headers, Windows + Python 2.x
    PR #4074 - close Client sockets if connection fails
    PR #4064 - Store default codemirror mode in only 1 place
    PR #4104 - Add way to install MathJax to a particular profile
    PR #4144 - help_end transformer shouldn't pick up ? in multiline string
    PR #4143 - update example custom.js
    PR #4142 - DOC: unwrap openssl line in public_server doc
    PR #4141 - add files with a separate add call in backport_pr
    PR #4137 - Restore autorestore option for storemagic
    PR #4098 - pass profile-dir instead of profile name to Kernel
    PR #4120 - support input in Python 2 kernels
    PR #4088 - nbconvert: Fix coalescestreams line with incorrect nesting causing strange behavior
    PR #4060 - only strip continuation prompts if regular prompts seen first
    PR #4132 - Fixed name error bug in function safe_unicode in module py3compat.
    PR #4121 - move test_kernel from IPython.zmq to IPython.kernel
    PR #4118 - ZMQ heartbeat channel: catch EINTR exceptions and continue.
    PR #4054 - use unicode for HTML export
    PR #4106 - fix a couple of default block values
    PR #4115 - Update docs on declaring a magic function
    PR #4101 - restore accidentally removed EngineError
    PR #4096 - minor docs changes
    PR #4056 - respect pylab_import_all when --pylab specified at the command-line
    PR #4091 - Make Qt console banner configurable
    PR #4086 - fix missing errno import
    PR #4030 - exclude .git in MANIFEST.in
    PR #4047 - Use istype() when checking if canned object is a dict
    PR #4031 - don't close_fds on Windows
    PR #4029 - bson.Binary moved
    PR #4035 - Fixed custom jinja2 templates being ignored when setting template_path
    PR #4026 - small doc fix in nbconvert
    PR #4016 - Fix IPython.start_* functions
    PR #4021 - Fix parallel.client.View map() on numpy arrays
    PR #4022 - DOC: fix links to matplotlib, notebook docs
    PR #4018 - Fix warning when running IPython.kernel tests
    PR #4019 - Test skipping without unicode paths
    PR #4008 - Transform code before %%prun/%%%%prun runs
    PR #4014 - Fix typo in ipapp
    PR #3987 - get files list in backport_pr
    PR #3974 - nbconvert: Fix app tests on Window7 w/ Python 3.3
    PR #3978 - fix --existing with non-localhost IP
    PR #3939 - minor checkpoint cleanup
    PR #3981 - BF: fix nbconvert rst input prompt spacing
    PR #3960 - Don't make sphinx a dependency for importing nbconvert
    PR #3973 - logging.Formatter is not new-style in 2.6
  Issues (18):
    [#4024] - nbconvert markdown issues
    [#4095] - Catch js error in append html in stream/pyerr
    [#4156] - Specifying --gui=tk at the command line
    [#3818] - nbconvert can't handle Heading with Chinese characters on Japanese Windows OS.
    [#4134] - multi-line parser fails on ''' in comment, qtconsole and notebook.
    [#3998] - sample custom.js needs to be updated
    [#4078] - StoreMagic.autorestore not working in 1.0.0
    [#3990] - Buitlin input doesn't work over zmq
    [#4015] - nbconvert fails to convert all the content of a notebook
    [#4059] - Issues with Ellipsis literal in Python 3
    [#4103] - Wrong default argument of DirectView.clear
    [#4100] - parallel.client.client references undefined error.EngineError
    [#4005] - IPython.start_kernel doesn't work.
    [#4020] - IPython parallel map fails on numpy arrays
    [#3945] - nbconvert: commandline tests fail Win7x64 Py3.3
    [#3977] - unable to complete remote connections for two-process
    [#3980] - nbconvert rst output lacks needed blank lines
    [#3968] - TypeError: super() argument 1 must be type, not classobj (Python 2.6.6)
* Wed Oct 23 2013 toddrme2178@gmail.com
- Don't try to install missing examples on openSUSE 12.2
* Wed Aug 21 2013 highwaystar.ru@gmail.com
- - update to 1.0.0
- The principal milestone is the addition of IPython.nbconvert.
- Added IPython.kernel for all kernel-related code.
- Removed the frontend subpackage, as it caused unnecessary depth.
- The IPython sphinx directives are now installed in IPython.sphinx.
- The input transformation framework has been reworked.
- Exception types can now be displayed with a custom traceback.
- A new command, ipython history trim can be used to delete everything but the last 1000 entries in the history database.
- __file__ is defined in both config files at load time, and .ipy files executed with %%run.
- %%logstart and %%logappend are no longer broken.
- Add glob expansion for %%run, e.g. %%run -g script.py *.txt.
- Expand variables ($foo) in Cell Magic argument line.
- By default, iptest will exclude various slow tests. All tests can be run with iptest –all.
- SQLite history can be disabled in the various cases that it does not behave well.
- %%edit works on interactively defined variables.
- editor hooks have been restored from quarantine, enabling TextMate as editor, etc.
- The env variable PYTHONSTARTUP is respected by IPython.
- The %%matplotlib magic was added.
- The --matplotlib command line flag was also added.
* Mon Jul 15 2013 speilicke@suse.com
- Set license to BSD-3-Clause according to legal team
* Wed Jun  5 2013 toddrme2178@gmail.com
- Install .desktop files
- Add buildrequires so there is proper detection of dependencies
  at build-time
- Add python-distribute buildrequires for proper dependency
  detection
- Build full documentation in python 2 version
  (not yet working with python 3)
- Include license file and README file
- Change suggests to recommends since suggests are not well
  supported
- Manually-specify executable and manual file names to better
  identify conflicts between python 2 and python 3 versions
* Fri May 17 2013 jmatejek@suse.com
- update to 0.13.2
  - bugfix-release, 52 bugs fixed
  - improved compatibility with new Qt versions
    (fixes bnc#819931, obsoletes ipython-fix-loading-newer-pyqt.diff)
- drop conditionals for too-old SUSE releases
- shorten summary
* Fri Mar 15 2013 lbeltrame@kde.org
- Add ipython-fix-loading-newer-pyqt.diff to make Qt console
  load with PyQt 4.10 (fix already upstream)
* Fri Nov 30 2012 toddrme2178@gmail.com
- Fix building on openSUSE 12.1 and 12.2
* Thu Nov 22 2012 toddrme2178@gmail.com
- Remove openSUSE 11.4 spec file workarounds
* Wed Oct 24 2012 einar@heavensinferno.net
- Remove the renames (now setuptools adds a -3 suffix automatically)
- Fix man pages (rename them accordingly, fixes rpmlint warning)
* Wed Oct 24 2012 einar@heavensinferno.net
- Update to 0.13.1
  - New major upstream release
  - Major notebook improvements
  - Major improvements to the Qt console
  - Improvement of parallel tools
  - Spec file adjustment: remove docs, since IPython-doc already
  provides them
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- added python3-tornado Requires for ipython3 notebook mode
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- fixed runtime Requires python3-xml and python3-distribute
* Fri Apr 27 2012 toddrme2178@gmail.com
- Update to 0.12.1
  Bugfixes
- Comment out non-existant wxpython-related python 3 packages
- Change python 3 binary names so they don't conflict with the
  python 2 ones
- Fix removal of hidden git info in python3 package
- Small python 2 package spec file cleanups
* Fri Apr 27 2012 highwaystar.ru@gmail.com
- added build dependency python3-2to3
  without it files just not converted silently
* Thu Feb  9 2012 highwaystar.ru@gmail.com
- added python3-IPython package
